==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/ChaikinVolatilityIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { ChaikinVolatilityIndicatorDescription } from "./ChaikinVolatilityIndicatorDescription";
/**
 * @hidden
 */
export let ChaikinVolatilityIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class ChaikinVolatilityIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (ChaikinVolatilityIndicatorDescriptionMetadata.a == null) {
                ChaikinVolatilityIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ChaikinVolatilityIndicatorDescriptionMetadata.c(ChaikinVolatilityIndicatorDescriptionMetadata.a);
            }
            if (a.k(ChaikinVolatilityIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.ab(ChaikinVolatilityIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            StrategyBasedIndicatorDescriptionMetadata.c(a);
            a.item("Period", "Number:int");
        }
        static d(a) {
            ChaikinVolatilityIndicatorDescriptionMetadata.b(a);
            a.ad("ChaikinVolatilityIndicator", () => new ChaikinVolatilityIndicatorDescription());
            a.ac("ChaikinVolatilityIndicator", ChaikinVolatilityIndicatorDescriptionMetadata.a);
        }
    }
    ChaikinVolatilityIndicatorDescriptionMetadata.$t = markType(ChaikinVolatilityIndicatorDescriptionMetadata, 'ChaikinVolatilityIndicatorDescriptionMetadata');
    ChaikinVolatilityIndicatorDescriptionMetadata.a = null;
    return ChaikinVolatilityIndicatorDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/ChaikinVolatilityIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { ChaikinVolatilityIndicatorDescription } from "./ChaikinVolatilityIndicatorDescription";
/**
 * @hidden
 */
export let ChaikinVolatilityIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class ChaikinVolatilityIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (ChaikinVolatilityIndicatorDescriptionMetadata.a == null) {
                ChaikinVolatilityIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ChaikinVolatilityIndicatorDescriptionMetadata.c(ChaikinVolatilityIndicatorDescriptionMetadata.a);
            }
            if (a.k(ChaikinVolatilityIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.ac(ChaikinVolatilityIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            StrategyBasedIndicatorDescriptionMetadata.c(a);
            a.item("Period", "Number:int");
        }
        static d(a) {
            ChaikinVolatilityIndicatorDescriptionMetadata.b(a);
            a.ae("ChaikinVolatilityIndicator", () => new ChaikinVolatilityIndicatorDescription());
            a.ad("ChaikinVolatilityIndicator", ChaikinVolatilityIndicatorDescriptionMetadata.a);
        }
    }
    ChaikinVolatilityIndicatorDescriptionMetadata.$t = markType(ChaikinVolatilityIndicatorDescriptionMetadata, 'ChaikinVolatilityIndicatorDescriptionMetadata');
    ChaikinVolatilityIndicatorDescriptionMetadata.a = null;
    return ChaikinVolatilityIndicatorDescriptionMetadata;
})();
